@@ -30,17 +30,27 @@ VALID_EVENT_TYPE = {
     "GetProductResponse" : "GetProductResponse",
 
     #Orders 
+    "OrderCreateRequest" : "OrderCreateRequest",
     "GetOrderRequest" : "GetOrderRequest",
     "GetOrderResponse" : "GetOrderResponse",
+    "ValidateOrderRequest" : "ValidateOrderRequest",
+    "VaildateOrderResponse" : "VaildateOrderResponse" ,
 
     #Delivery
     "ScheduledOrderItem" : "ScheduledOrderItem",
     "PackagingStatusUpdate" : "PackagingStatusUpdate",
+    "TrackingGenerateRequest" : "TrackingGenerateRequest",
+    "TrackingGenerateResponse" : "TrackingGenerateResponse",
+    "UpdateOrderScheduleRequest" : "UpdateOrderScheduleRequest",
+    "UpdateOrderScheduleResponse" : "UpdateOrderScheduleResponse",
+    
+    "OrderItemDeliverySchedule" :"OrderItemDeliverySchedule" ,
+    "OrderItemPackageStatus" : "OrderItemPackageStatus",
+    
 
     #Invoice & Payment
     "InvoiceGenerateRequest" : "InvoiceGenerateRequest",
     "InvoiceGenerateResponse" : "InvoiceGenerateResponse",
-
     "PaymentProcessRequest" : "PaymentProcessRequest",
     "PaymentProcessResponse" : "PaymentProcessResponse"
 }
