@@ -69,4 +69,8 @@ def get_source(event: dict):
     elif 'operation' in event and 'message' in event:
         return 'is_mobile_backend'
     elif 'source' in event and 'detail-type' in event:
-        return  'event-bridge'
\ No newline at end of file
+        return  'event-bridge'
+    elif 'eventType' in event and event['eventType'] == 'request_response':
+        return  'request_response'
+    else :
+        return 'unknown'
